@@ -143,6 +143,11 @@ PangoFontDescription *pango_win32_font_description_from_logfont (const LOGFONTA
 PANGO_AVAILABLE_IN_1_16
 PangoFontDescription *pango_win32_font_description_from_logfontw (const LOGFONTW *lfp);
 
+PANGO_AVAILABLE_IN_1_52
+gboolean              pango_win32_font_map_add_font_file (PangoFontMap       *font_map,
+                                                          const char         *font_file_path,
+                                                          GError            **error);
+
 G_END_DECLS
 
 #endif /* __PANGOWIN32_H__ */
